@@ -20,5 +20,5 @@ from .demo_ARMA import ARMA
 from .demo_Solow import Solow
 from .demo_Markov import Markov
 from .demo_filters import filters
-from .demo_BoxJenkins import BoxJenkins
+# from .demo_BoxJenkins import BoxJenkins # still work in progress
 
