@@ -1,7 +1,7 @@
 """
 demo_filters: Module for learning about time series filters to measure the business cycle
 
-This module provides a single function, filters_demo(), which creates a dash consisting of 3 tabs with a single plot in
+This module provides a single function, filters(), which creates a dash consisting of 3 tabs with a single plot in
 each of them, to compare the business cycle measurement implied by different filters. The plots display
     1. The original data and trend
     2. the cyclical component
@@ -420,7 +420,7 @@ app.layout = html.Div(children=[
                              ]),
                  ]),
              ]),
-    make_bottom_banner('macrodemos.filters_demo( )', width=20)
+    make_bottom_banner('macrodemos.filters( )', width=20)
 ],
     style={'backgroundColor': colors['background']})
 
@@ -520,14 +520,15 @@ def update_plots(n_clicks, indicator, whichFilters, lambda_, K, pL, pH, cfpL, cf
 This block executes the app
 """
 
-def filters_demo(colab=False):
+def filters(colab=False):
     if colab:
         app.run_server(mode='external')
     else:
         webbrowser.open('http://127.0.0.1:8050/')
         app.run_server(debug=False)
 
+filters_demo = filters # kept for backward compatibility
 
 if __name__ == '__main__':
-    filters_demo()
+    filters()
 
